.. This file provides the instructions for how to display the API documentation generated using sphinx autodoc
   extension. Use it to declare Python documentation sub-directories via appropriate modules (automodule, etc.).

Automation Tools
================

.. automodule:: ataraxis_automation.automation
   :members:
   :undoc-members:
   :show-inheritance:

CLI Commands
============

.. click:: ataraxis_automation.automation:cli
   :prog: automation-cli
   :nested: full
